<?php

namespace OCA\UPschooling\Tests\Integration\Controller;

use OCA\UPschooling\Db\MatrixUser;
use OCA\UPschooling\Db\UserMapper;
use OCP\AppFramework\App;
use OCP\IRequest;
use PHPUnit\Framework\TestCase;


class MatrixUserIntegrationTest extends TestCase {
	private $mapper;
	private $userId = 'john';
	private $matrixUserId = '@john:synapse';

	public function setUp(): void {
		$app = new App('upschooling');
		$container = $app->getContainer();

		// only replace the user id
		$container->registerService('userId', function () {
			return $this->userId;
		});

		// we do not care about the request but the controller needs it
		$container->registerService(IRequest::class, function () {
			return $this->createMock(IRequest::class);
		});

		$this->mapper = $container->query(UserMapper::class);
	}

	public function testUpdate() {
		// create a new user
		$user = new MatrixUser();
        $user->setMatrixUser($this->matrixUserId);
        $user->setUserId($this->userId);

		$this->mapper->insert($user);

        // test that user is in database
        $result = $this->mapper->find($this->userId);
		$this->assertEquals($user, $result->getData());

		// clean up
		$this->mapper->delete($result->getData());
	}
}
